Package: hdi
Type: Package
Title: High-Dimensional Inference
Version: 0.1-9
Date: 2021-05-27
Author: Lukas Meier [aut, cre], Ruben Dezeure [aut], Nicolai Meinshausen [aut], Martin Maechler [aut], Peter Buehlmann [aut]
Maintainer: Lukas Meier <meier@stat.math.ethz.ch>
Description: Implementation of multiple approaches to perform inference in high-dimensional models.
Depends: scalreg
DependsNote: scalreg does not correctly import lars etc, so we need to
        depend on it
Imports: grDevices, graphics, stats, parallel, MASS, glmnet, linprog
Suggests: Matrix
SuggestsNote: for tests only
Encoding: UTF-8
License: GPL
NeedsCompilation: no
Packaged: 2021-05-27 12:25:06 UTC; meierluk
Repository: CRAN
Date/Publication: 2021-05-27 13:10:02 UTC
Built: R 4.4.0; ; 2024-05-01 04:25:23 UTC; unix
