## Imports from standard R packages
importFrom("grDevices", rgb)
importFrom("graphics", axis, lines, plot, points)
importFrom("stats", anova, approxfun, as.dist, coef, confint,
           cor, cutree, ecdf, glm, hclust, lm, median,
           p.adjust, p.adjust.methods, pnorm, predict, pt,
           qnorm, qt, quantile, rnorm, runif, sd, setNames,
           toeplitz, vcov)
importFrom("parallel", mclapply, mcmapply)

## Imports from Recommended R packages
importFrom("MASS", mvrnorm)

## Further Imports
importFrom("glmnet", glmnet, cv.glmnet)
importFrom("linprog", solveLP)
importFrom("scalreg", scalreg)

## Exports
export(hdi, fdr.adjust, stability,
       lasso.firstq, lasso.proj, lasso.cv,
       boot.lasso.proj,
       ridge.proj,
       lm.pval, lm.ci, glm.pval,
       multi.split,
       rXb,
       rX,
       clusterGroupBound,
       groupBound)

## S3 methods :
S3method(print, hdi)
S3method(confint, hdi)
S3method(plot, clusterGroupBound)
S3method(plot, clusterGroupTest)
